// 1. 导入dayjs
import dayjs from 'dayjs';
// 2. dayjs 默认语言是英文，我们这里配置为中文
import 'dayjs/locale/zh-cn';
// 3. 引入 relativeTime
import rTime from 'dayjs/plugin/relativeTime';
// 4. 加载中文语言包
dayjs.locale('zh-cn');
// 5. 加载相对时间插件
dayjs.extend(rTime);

// 时间处理

const timeFix = function() {
  const time = new Date();
  const hour = time.getHours();
  return hour < 9
    ? '早上好'
    : hour <= 11
    ? '上午好'
    : hour <= 13
    ? '中午好'
    : hour < 20
    ? '下午好'
    : '晚上好';
};

/*
 * StartYear 开始年份 参数为空时为当前年份前5年
 * endYear 结束年份 参数为空时为当前年份
 */
const getYearArr = (startYear, endYear) => {
  const yearArr = [];
  const prDate = new Date();
  const presentYear = prDate.getFullYear(); // 当前年份
  if (!endYear) {
    // 为空为当前年份
    endYear = presentYear;
  }
  if (!startYear) {
    // 为空为当前年前5年
    startYear = presentYear - 5;
  }
  for (let i = startYear; i <= endYear; i++) {
    yearArr.push(parseInt(i));
  }
  return yearArr;
};

// 判断参数是否为空
const isNotEmpty = str => {
  if (str !== '' && str !== null && typeof str !== 'undefined') {
    return true;
  }
  // console.warn('argument format is wrong');
  return false;
};

// 字符时间转Date类型
const formatToDate = dateStr => {
  if (isNotEmpty(dateStr)) {
    return new Date(Date.parse(dateStr.replace(/-/g, '/')));
  }
  return '';
};

/**
 * 6. 定义过滤器，通过 dayjs().to(dayjs(val)) 方法把【当前时间】处理为【相对时间】
 * 2年前，1个月前 这种相对时间
 */
const relativeTime = function(val) {
  if (isNotEmpty(val)) {
    return dayjs().to(dayjs(val));
  }
};

export { timeFix, relativeTime, getYearArr, formatToDate };
